#!/usr/bin/env python3
import sys
from sys import argv
import socket
from typing import List

from de.p1st.exec_notify.lib import exec, config, mail


def main():
    if len(argv) <= 1:
        print('No command given to execute!', file=sys.stderr)
        exit(1)

    exit(executeCommand(argv[1:]))


def executeCommand(command: List) -> int:
    """
    Executes the given command and sends an email on failure.

    :return: exit code of executed command
    """

    keys = ['command', 'exit code', 'stderr', 'stdout']
    exitCode, stdout, stderr = exec.execute(command)
    values = [str(command), str(exitCode), stderr, stdout]

    BODY = ''
    for key, value in zip(keys, values):
        BODY += '=== {} ===\n{}\n'.format(key, value)
    print(BODY)

    if exitCode != 0:
        hostname = socket.gethostname()

        SUBJECT = '{} | {}'.format(hostname, str(command))
        mail.sendMailOrWriteToFile(SUBJECT=SUBJECT, BODY=BODY)

    return exitCode


if __name__ == '__main__':
    main()
